## Python Guidelines

- Use English for variables, methods, classes, and prints.
- Use single quotes (') instead of double quotes (").
- Do not add comments to the code.
- Variable names should be descriptive and in snake_case.
- Class names should be in CamelCase.
- Apply PEP8 rules when writing code.
- Do not exceed 80 characters per line.
- To install libraries, we use poetry.
